@@ -48,14 +48,13 @@ class custom_canvas(canvas):
         self.method_grid()
 
 
-
 class customize(canvas, attributes):
 
     def __init__(self,
-                 # Base
-                 backend=None,
+                 # Backend
+                 backend='Qt5Agg',
                  # Fonts
-                 font='serif', math_font="dejavusans", font_color="black",
+                 font='serif', math_font="dejavuserif", font_color="black",
                  # Figure, axes
                  fig=None, ax=None, figsize=None, shape_and_position=111, prune=None, resize_axes=True, aspect=None,
                  # Setup
@@ -63,7 +62,7 @@ class customize(canvas, attributes):
                  background_color_figure='white', background_color_plot='white', background_alpha=1,
                  style=None, light=None, dark=None,
                  # Spines
-                 spine_color=None, spines_removed=('top', 'right'),
+                 spine_color=None, spines_removed=(0, 0, 1, 1),
                  # Bounds
                  x_upper_bound=None, x_lower_bound=None,
                  y_upper_bound=None, y_lower_bound=None,
@@ -73,9 +72,9 @@ class customize(canvas, attributes):
                  x_upper_resize_pad=0, x_lower_resize_pad=0,
                  y_upper_resize_pad=0, y_lower_resize_pad=0,
                  # Grid
-                 grid=False, grid_color='lightgrey', grid_lines='-.',
+                 grid=True, grid_color='lightgrey', grid_lines='-.',
                  # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
+                 color='darkred', cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title=None, title_size=12, title_y=1.025, title_weight=None, title_font=None, title_color=None,
                  # Labels
@@ -84,27 +83,35 @@ class customize(canvas, attributes):
                  # Ticks
                  x_tick_number=5, x_tick_labels=None,
                  y_tick_number=5, y_tick_labels=None,
-                 x_tick_rotation=None, y_tick_rotation=None, x_label_coords=None, y_label_coords=None,
-                 tick_color=None, tick_label_pad=5, tick_ndecimals=1,
+                 x_label_coords=None, y_label_coords=None,
+                 tick_color=None, tick_label_pad=5,
+                 ticks_where=(1, 1, 0, 0),
                  # Tick labels
                  tick_label_size=None, tick_label_size_x=None, tick_label_size_y=None,
                  custom_x_tick_locations=None, custom_y_tick_locations=None, fine_tick_locations=True,
                  custom_x_tick_labels=None, custom_y_tick_labels=None,
                  date_tick_labels_x=False, date_format='%Y-%m-%d',
+                 tick_ndecimals=1, tick_ndecimals_x=None, tick_ndecimals_y=None,
+                 x_tick_rotation=None, y_tick_rotation=None,
+                 tick_labels_where=(1, 1, 0, 0),
                  # Color bar
-                 color_bar=False, cb_pad=0.2, extend='neither',
-                 cb_title=None, cb_orientation='vertical', cb_axis_labelpad=10, cb_tick_number=5, shrink=0.75,
-                 cb_outline_width=None, cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
+                 color_bar=False, cb_pad=0.2, cb_axis_labelpad=10, shrink=0.75, extend='neither',
+                 cb_title=None, cb_orientation='vertical',
+                 cb_title_rotation=None, cb_title_style='normal', cb_title_size=10,
                  cb_top_title_y=1, cb_ytitle_labelpad=10, cb_title_weight='normal', cb_top_title=False,
-                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0, cb_vmin=None, cb_vmax=None,
-                 cb_ticklabelsize=10, cb_hard_bounds=False,
+                 cb_y_title=False, cb_top_title_pad=None, cb_top_title_x=0,
+                 cb_vmin=None, cb_vmax=None, cb_hard_bounds=False, cb_outline_width=None,
+                 cb_tick_number=5, cb_ticklabelsize=10, tick_ndecimals_cb=None,
                  # Legend
-                 legend=False, legend_loc='upper right', legend_size=13, legend_weight='normal',
+                 legend=False, legend_loc='upper right', legend_bbox_to_anchor=None,
+                 legend_size=13, legend_weight='normal',
                  legend_style='normal', legend_handleheight=None, legend_ncol=1,
                  # Subplots
-                 more_subplots_left=True, zorder=None,
+                 show=False, zorder=None,
                  # Save
                  filename=None, dpi=None,
+                 # Suppress output
+                 suppress=True
                  ):
 
         """
