@@ -65,7 +65,7 @@ class canvas:
         self.fig = self.plt.figure(figsize=self.figsize)
 
     def method_grid(self):
-        if self.grid is not False:
+        if self.grid:
             self.ax.grid(linestyle=self.grid_lines, color=self.grid_color)
 
 
@@ -310,8 +310,9 @@ class attributes:
         """
         Defaults
         """
-        if np.all(self.y == self.y[0]):
-            self.fine_tick_locations = False
+        if not isinstance(self.y, type(None)):
+            if np.all(self.y == self.y[0]):
+                self.fine_tick_locations = False
         if self.fine_tick_locations is True:
             if not isinstance(self.x, type(None)) and isinstance(self.custom_x_tick_locations, type(None)):
                 self.custom_x_tick_locations = [self.x.min(), self.x.max()]
